LevelPlay class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getNativeSDKVersion(
String platform) → String -
Returns the native SDK version for
platform. -
getPluginVersion(
) → String - Returns the plugin version.
-
init(
{required LevelPlayInitRequest initRequest, required LevelPlayInitListener initListener}) → Future< void> -
Initializes the LevelPlay SDK with
appKeyforadFormats.