LevelPlayNativeAdTemplateStyle class

Class for styling native ad elements

Constructors

LevelPlayNativeAdTemplateStyle({Color? mainBackgroundColor, LevelPlayNativeAdElementStyle? titleStyle, LevelPlayNativeAdElementStyle? bodyStyle, LevelPlayNativeAdElementStyle? advertiserStyle, LevelPlayNativeAdElementStyle? callToActionStyle})

Properties

advertiserStyle LevelPlayNativeAdElementStyle?
final
bodyStyle LevelPlayNativeAdElementStyle?
final
callToActionStyle LevelPlayNativeAdElementStyle?
final
hashCode int
The hash code for this object.
no setterinherited
mainBackgroundColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleStyle LevelPlayNativeAdElementStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited